/***********************************************************************************************************************************
Start Command
***********************************************************************************************************************************/
#ifndef COMMAND_CONTROL_START_H
#define COMMAND_CONTROL_START_H

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
FN_EXTERN void cmdStart(void);

#endif
